WavelengthSpace
===============

.. currentmodule:: spdcalc.spdcalc

.. autoclass:: WavelengthSpace
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~WavelengthSpace.from_frequency_space
      ~WavelengthSpace.from_sum_diff_frequency_space
      ~WavelengthSpace.set_resolution
      ~WavelengthSpace.to_frequency_space
      ~WavelengthSpace.to_sum_diff_frequency_space

   .. rubric:: Methods Documentation

   .. automethod:: from_frequency_space
   .. automethod:: from_sum_diff_frequency_space
   .. automethod:: set_resolution
   .. automethod:: to_frequency_space
   .. automethod:: to_sum_diff_frequency_space
